<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ArtNetPlugin</name>
    <message>
        <location filename="artnetplugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the ArtNet communication protocol.</source>
        <translation>Tento plugin přidává podporu DMX výstupů pro zařízení podporující komunikační protokol ArtNet.</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="148"/>
        <location filename="artnetplugin.cpp" line="298"/>
        <source>Status: Not open</source>
        <translation>Stav: Neotevřený</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="151"/>
        <source>Status: Open</source>
        <translation>Stav: Otevřený</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="156"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="158"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="159"/>
        <source>Can receive nodes information</source>
        <oldsource>Can receive node information</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="162"/>
        <source>Nodes discovered: </source>
        <translation>Nalezené uzly:</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="165"/>
        <source>Packets sent: </source>
        <translation>Odeslané pakety:</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="294"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="303"/>
        <source>Bind failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="305"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="306"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="309"/>
        <source>Packets received: </source>
        <translation>Přijaté pakety:</translation>
    </message>
</context>
<context>
    <name>ConfigureArtNet</name>
    <message>
        <location filename="configureartnet.ui" line="33"/>
        <source>Configure ArtNet Plugin</source>
        <translation>Konfigurace ArtNet pluginu</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="49"/>
        <source>Configuration of the patched universes</source>
        <translation>Konfigurace propojených větví</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="57"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="62"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="67"/>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="72"/>
        <source>ArtNet Universe</source>
        <translation>Větev ArtNet</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="77"/>
        <source>Transmission Mode</source>
        <translation>Spůsob přenosu</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="87"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="120"/>
        <source>Nodes Tree</source>
        <translation>Strom uzlů</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="130"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="135"/>
        <source>Short Name</source>
        <translation>Zkrácený název</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="140"/>
        <source>Long Name</source>
        <translation>Dlouhý název</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="86"/>
        <source>%1 nodes</source>
        <translation>Uzly %1</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="124"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="130"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="181"/>
        <source>Standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="182"/>
        <source>Full</source>
        <translation>Plný</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="183"/>
        <source>Partial</source>
        <translation>Částečný</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="198"/>
        <source>Invalid IP</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="198"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 není platná IP adresa. Prosím opravte.</translation>
    </message>
</context>
</TS>
